==> haskell-hls-ormolu-plugin-1.0.4.0-52.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-ormolu-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-ormolu-plugin
version:              1.0.4.0
visibility:           public
id:                   hls-ormolu-plugin-1.0.4.0-B08VcTHfAlW5p6poc1iSZs
key:                  hls-ormolu-plugin-1.0.4.0-B08VcTHfAlW5p6poc1iSZs
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Integration with the Ormolu code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  ad8ea1a26624bbd6d63c765aaacbea85
exposed:              True
exposed-modules:      Ide.Plugin.Ormolu
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hls-ormolu-plugin-1.0.4.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hls-ormolu-plugin-1.0.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-ormolu-plugin
hs-libraries:         HShls-ormolu-plugin-1.0.4.0-B08VcTHfAlW5p6poc1iSZs
depends:
    base-4.16.4.0 filepath-1.4.2.2 ghc-9.2.8 ghc-boot-th-9.2.8
    ghcide-1.9.1.0-HwAkVTDd37EFvNbRQNs88T
    hls-plugin-api-1.6.0.0-6Ebop0G4HfEC83Y5bnhsUu
    lens-5.2.3-Lr9JV2q3Rgv6Xn7f42cFjs
    lsp-1.6.0.0-1JAbQDnc0SK1hycTz4LLrJ
    ormolu-0.5.0.1-C9wzwjZiI3XAMrJJ1m6KB4 text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-hls-ormolu-plugin/html/hls-ormolu-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-ormolu-plugin/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-ormolu-plugin-1.0.4.0-97-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-ormolu-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-ormolu-plugin
version:              1.0.4.0
visibility:           public
id:                   hls-ormolu-plugin-1.0.4.0-IzeM4K2ByF1GEgFZXacSYR
key:                  hls-ormolu-plugin-1.0.4.0-IzeM4K2ByF1GEgFZXacSYR
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Integration with the Ormolu code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  1ff44c2e63824702a89e3ada0344b7c8
exposed:              True
exposed-modules:      Ide.Plugin.Ormolu
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hls-ormolu-plugin-1.0.4.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hls-ormolu-plugin-1.0.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-ormolu-plugin
hs-libraries:         HShls-ormolu-plugin-1.0.4.0-IzeM4K2ByF1GEgFZXacSYR
depends:
    base-4.16.4.0 filepath-1.4.2.2 ghc-9.2.8 ghc-boot-th-9.2.8
    ghcide-1.10.0.0-42asgJmBwLYDXfQ3kee4Wu
    hls-plugin-api-1.6.0.0-GBhVrEAXY9G7a8rlmXAPNi
    lens-5.2.3-JhnKgAx9k76Jin0xTqnLw0
    lsp-1.6.0.0-3mgfXrOs4nYBY8raCTSUiO
    ormolu-0.5.0.1-17i7JqrJ5rYI3vfKP9BmQ text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-hls-ormolu-plugin/html/hls-ormolu-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-ormolu-plugin/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
